==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/Input/mpeg/translations/mpeg_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="166"/>
        <source>MPEG Plugin</source>
        <translation>MPEG Module</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="169"/>
        <source>MPEG Files</source>
        <translation>MPEG Bestanden</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="377"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Over de MPEG Audio Module</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="378"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="379"/>
        <source>Compiled against:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="388"/>
        <source>mpg123, API version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="392"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="393"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Broncode gebasseerd op &apos;mq3&apos; en &apos;madplay&apos; projecten</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="65"/>
        <location filename="../mpegmetadatamodel.cpp" line="68"/>
        <location filename="../mpegmetadatamodel.cpp" line="71"/>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Mode</source>
        <translation>Stand</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="77"/>
        <source>Protection</source>
        <translation>Bescherming</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="79"/>
        <source>Original</source>
        <translation>Origineel</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>MPEG Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Tag Priority</source>
        <translation>Tag prioriteit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>First:</source>
        <translation>Primair:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>ID3v1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <location filename="../settingsdialog.ui" line="163"/>
        <location filename="../settingsdialog.ui" line="212"/>
        <source>ID3v2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>APE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>Second:</source>
        <translation>Secundair:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="187"/>
        <source>Third:</source>
        <translation>Tertiair:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="252"/>
        <source>Encodings</source>
        <translation>Codering</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="264"/>
        <source>ID3v1 encoding:</source>
        <translation>ID3v1 codering:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="290"/>
        <source>ID3v2 encoding:</source>
        <translation>ID3v2 codering:</translation>
    </message>
</context>
</TS>

==> qmmp_1.3.4.orig.tar.bz2: qmmp-1.3.4/src/plugins/Input/mpeg/translations/mpeg_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="175"/>
        <source>MPEG Plugin</source>
        <translation>MPEG Module</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="178"/>
        <source>MPEG Files</source>
        <translation>MPEG Bestanden</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="386"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Over de MPEG Audio Module</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="387"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation>MPEG 1.0/2.0/2.5 layer 1/2/3-audiodecoder</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="388"/>
        <source>Compiled against:</source>
        <translation>Gebouwd met</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="397"/>
        <source>mpg123, API version: %1</source>
        <translation>mpg123, API version: %1</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="401"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="402"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Broncode gebasseerd op &apos;mq3&apos; en &apos;madplay&apos; projecten</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="65"/>
        <location filename="../mpegmetadatamodel.cpp" line="68"/>
        <location filename="../mpegmetadatamodel.cpp" line="71"/>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Mode</source>
        <translation>Stand</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="77"/>
        <source>Protection</source>
        <translation>Bescherming</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="79"/>
        <source>Original</source>
        <translation>Origineel</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>MPEG Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation>Decoder</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation>MAD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation>MPG123</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Tag Priority</source>
        <translation>Tag prioriteit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>First:</source>
        <translation>Primair:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <location filename="../settingsdialog.ui" line="163"/>
        <location filename="../settingsdialog.ui" line="212"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>Second:</source>
        <translation>Secundair:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="187"/>
        <source>Third:</source>
        <translation>Tertiair:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="252"/>
        <source>Encodings</source>
        <translation>Codering</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="264"/>
        <source>ID3v1 encoding:</source>
        <translation>ID3v1 codering:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="290"/>
        <source>ID3v2 encoding:</source>
        <translation>ID3v2 codering:</translation>
    </message>
</context>
</TS>
